@@ -49,6 +49,10 @@
 #include <stdint.h>
 #endif
 
+#ifdef HAVE_LIMITS_H
+#include <limits.h>
+#endif
+
 #ifndef HAVE_STRNSTR
 #define strnstr(s, find, slen) ci_strnstr(s, find, slen)
 #endif
