@@ -24,6 +24,10 @@
 #include "net_io.h"
 #include "types_ops.h"
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
 
 /**
  \defgroup ACL Access lists API
@@ -71,7 +75,7 @@ typedef struct ci_acl_type{
     /**
        \brief Pointer to the ci_types_ops_t struct which implements basic operations for the acl test data
      */
-     ci_type_ops_t *type;
+     const ci_type_ops_t *type;
 } ci_acl_type_t;
 
 struct ci_acl_type_list{
@@ -171,7 +175,7 @@ CI_DECLARE_FUNC(const ci_acl_spec_t *) ci_access_entry_add_acl(ci_access_entry_t
    \param aclname The name of the acl to be added.
    \return non zero on success, zero otherwise
  */
-CI_DECLARE_FUNC(int) ci_access_entry_add_acl_by_name(ci_access_entry_t *access_entry, char *aclname);
+CI_DECLARE_FUNC(int) ci_access_entry_add_acl_by_name(ci_access_entry_t *access_entry, const char *aclname);
 
 /**
    \brief Check if an access entries list matches a request object
@@ -199,6 +203,7 @@ CI_DECLARE_FUNC(void) ci_acl_init();
 CI_DECLARE_FUNC(void) ci_acl_reset();
 
 CI_DECLARE_FUNC(const ci_acl_spec_t *) ci_acl_search(const char *name);
+CI_DECLARE_FUNC(int) ci_acl_add_data(const char *name, const char *type, const char *data);
 
 /**
    \brief Search for an acl type
@@ -218,4 +223,8 @@ CI_DECLARE_FUNC(const ci_acl_type_t *) ci_acl_type_search(const char *name);
  */
 CI_DECLARE_FUNC(int) ci_acl_type_add(const ci_acl_type_t *type);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif/* __ACL_H*/
