@@ -59,6 +59,27 @@ typedef struct ci_array {
     ci_mem_allocator_t *alloc;
 } ci_array_t;
 
+/**
+ \def ci_array_value(array, pos)
+ \ingroup SIMPLE_ARRAYS
+ * Return the value of item on position 'pos'
+ */
+#define ci_array_value(array, pos) (pos < (array)->count ?  (array)->items[pos].value : NULL)
+
+/**
+ \def ci_array_name(array, pos)
+ \ingroup SIMPLE_ARRAYS
+ * Return the name of item on position 'pos'
+ */
+#define ci_array_name(array, pos) (pos < (array)->count ?  (array)->items[pos].name : NULL)
+
+/**
+ \def ci_array_size(array)
+ \ingroup SIMPLE_ARRAYS
+ * Return the size of array 'array'
+ */
+#define ci_array_size(array) ((array)->count)
+
 /**
  * Allocate the required memory and initialize an ci_array_t object 
  \ingroup SIMPLE_ARRAYS
@@ -154,6 +175,9 @@ typedef ci_array_t ci_str_array_t;
 #define ci_str_array_get_item(array, pos) ci_array_get_item(array, pos)
 #define ci_str_array_search(array, name) (const char *)ci_array_search(array, name)
 #define ci_str_array_iterate ci_array_iterate
+#define ci_str_array_value(array, pos) ci_array_value(array, pos)
+#define ci_str_array_name(array, pos) ci_array_name(array, pos)
+#define ci_str_array_size(array) ci_array_size(array)
 
 
 /**
@@ -171,6 +195,27 @@ typedef ci_array_t ci_str_array_t;
  */
 typedef ci_array_t ci_ptr_array_t;
 
+/**
+ \def ci_ptr_array_value(ptr_array, pos)
+ \ingroup PTR_ARRAYS
+ * Return the value of item at position 'pos'
+ */
+#define ci_ptr_array_value(array, pos) ci_array_value(array, pos)
+
+/**
+ \def ci_ptr_array_value(ptr_array, pos)
+ \ingroup PTR_ARRAYS
+ * Return the name of item at position 'pos'
+ */
+#define ci_ptr_array_name(array, pos) ci_array_name(array, pos)
+
+/**
+ \def ci_ptr_array_value(ptr_array)
+ \ingroup PTR_ARRAYS
+ * Return the size of ptr_array
+ */
+#define ci_ptr_array_size(array) ci_array_size(array)
+
 /**
  \def ci_ptr_array_new()
  \ingroup PTR_ARRAYS
@@ -254,12 +299,6 @@ CI_DECLARE_FUNC(void *) ci_ptr_array_pop_value(ci_ptr_array_t *ptr_array, char *
  *
  */
 
-typedef struct ci_dyn_array_item{
-    char *name;
-    void *value;
-    struct ci_dyn_array_item *next;
-} ci_dyn_array_item_t;
-
 /**
  \typedef ci_dyn_array_t
  \ingroup DYNAMIC_ARRAYS
@@ -268,20 +307,48 @@ typedef struct ci_dyn_array_item{
  * before the ci_dyn_array destroyed.
  */
 typedef struct ci_dyn_array {
-    ci_dyn_array_item_t *items;
-    ci_dyn_array_item_t *last;
-    size_t max_size;
+    ci_array_item_t **items;
+    int count;
+    int max_items;
     ci_mem_allocator_t *alloc;
 } ci_dyn_array_t;
 
+/**
+ \def ci_dyn_array_get_item(array, pos)
+ \ingroup DYNAMIC_ARRAYS
+ * Return the ci_array_item_t item on position 'pos'
+ */
+#define ci_dyn_array_get_item(array, pos) (pos < (array)->count ? (array)->items[pos] : NULL)
+
+/**
+ \def ci_dyn_array_value(array, pos)
+ \ingroup DYNAMIC_ARRAYS
+ * Return the value of item on position 'pos'
+ */
+#define ci_dyn_array_value(array, pos) ((pos < (array)->count && (array)->items[pos] != NULL) ?  (array)->items[pos]->value : NULL)
+
+/**
+ \def ci_dyn_array_name(array, pos)
+ \ingroup DYNAMIC_ARRAYS
+ * Return the name of item on position 'pos'
+ */
+#define ci_dyn_array_name(array, pos) ((pos < (array)->count && (array)->items[pos] != NULL) ?  (array)->items[pos]->name : NULL)
+
+/**
+ \def ci_dyn_array_size(array)
+ \ingroup DYNAMIC_ARRAYS
+ * Return the size of array 'array'
+ */
+#define ci_dyn_array_size(array) ((array)->count)
+
 /**
  * Allocate the required memory and initialize an ci_dyn_array_t object 
  \ingroup DYNAMIC_ARRAYS
- \param max_mem_size the maximum memory to use
+ \param mem_size the initial size to use for dyn_array
  \return the allocated object on success, or NULL on failure
  *
  */
-CI_DECLARE_FUNC(ci_dyn_array_t *) ci_dyn_array_new(size_t max_mem_size);
+CI_DECLARE_FUNC(ci_dyn_array_t *) ci_dyn_array_new(size_t mem_size);
 
 /**
  * Create and initialize an ci_dyn_array_t object for the given number of items
@@ -308,7 +375,7 @@ CI_DECLARE_FUNC(void) ci_dyn_array_destroy(ci_dyn_array_t *array);
  \param size the size of the value part of the new item.
  \return a pointer to the new array item on success, NULL otherwise
  */
-CI_DECLARE_FUNC(const ci_dyn_array_item_t *) ci_dyn_array_add(ci_dyn_array_t *array, const char *name, const void *value, size_t size);
+CI_DECLARE_FUNC(const ci_array_item_t *) ci_dyn_array_add(ci_dyn_array_t *array, const char *name, const void *value, size_t size);
 
 /**
  * Search in an dynamic array for an item with the given name
@@ -344,11 +411,17 @@ CI_DECLARE_FUNC(void) ci_dyn_array_iterate(const ci_dyn_array_t *array, void *da
  * functions with the required typecasting.
  */
 typedef ci_dyn_array_t ci_ptr_dyn_array_t;
-#define ci_ptr_dyn_array_new ci_dyn_array_new
+#define ci_ptr_dyn_array_new(size) ci_dyn_array_new(size)
+#define ci_ptr_dyn_array_new2(items, item_size) ci_dyn_array_new2(items, item_size)
 #define ci_ptr_dyn_array_destroy(ptr_array) ci_dyn_array_destroy(ptr_array)
 #define ci_ptr_dyn_array_search(ptr_array, name) ci_dyn_array_search(ptr_array, name)
 #define ci_ptr_dyn_array_iterate(ptr_array, data, fn) ci_dyn_array_iterate(ptr_array, data, fn)
 
+#define ci_ptr_dyn_array_get_item(array, pos) ci_dyn_array_get_item(array, pos)
+#define ci_ptr_dyn_array_value(array, pos) ci_dyn_array_value(array, pos)
+#define ci_ptr_dyn_array_name(array, pos) ci_dyn_array_name(array, pos)
+#define ci_ptr_dyn_array_size(array) ci_dyn_array_size(array)
+
 /**
  * Add an name/value pair item to the array.
  \ingroup  PTR_DYNAMIC_ARRAYS
@@ -357,7 +430,7 @@ typedef ci_dyn_array_t ci_ptr_dyn_array_t;
  \param pointer the pointer part of the name/value pair item to be added
  \return a pointer to the new array item on success, NULL otherwise
  */
-CI_DECLARE_FUNC(const ci_dyn_array_item_t *) ci_ptr_dyn_array_add(ci_ptr_dyn_array_t *ptr_array, const char *name, void *pointer);
+CI_DECLARE_FUNC(const ci_array_item_t *) ci_ptr_dyn_array_add(ci_ptr_dyn_array_t *ptr_array, const char *name, void *pointer);
 
 
 /**
@@ -527,6 +600,7 @@ typedef struct ci_list {
     ci_list_item_t *last;
     ci_list_item_t *trash;
     ci_list_item_t *cursor;
+    ci_list_item_t *tmp;
     size_t obj_size;
     ci_mem_allocator_t *alloc;
 
@@ -544,6 +618,42 @@ typedef struct ci_list {
  */
 CI_DECLARE_FUNC(ci_list_t *) ci_list_create(size_t init_size, size_t obj_size);
 
+/**
+ \def ci_list_first(ci_list_t *list)
+ * Gets the first item of the list and updates the list cursor to the next item.
+ * WARNING: do not mix this macro with ci_list_iterate. Use the ci_list_head/ci_list_tail macros instead
+ \ingroup LISTS
+ \param list  a pointer to the ci_list_t object
+ \return The first item if exist, NULL otherwise
+ */
+#define ci_list_first(list) ((list)->items && (((list)->cursor = (list)->items->next) != NULL || 1) ? (list)->items->item : NULL)
+
+
+/**
+ \def ci_list_next()
+ * Return the next item of the list and updates the list cursor to the next item.
+ * WARNING: do not mix this macro with ci_list_iterate!
+ \ingroup LISTS
+ \param list  a pointer to the ci_list_t object
+ \return The next item if exist, NULL otherwise
+*/
+#define ci_list_next(list) (((list)->tmp = (list)->cursor) != NULL && (((list)->cursor = (list)->cursor->next) != NULL || 1) ? (list)->tmp->item : NULL)
+
+
+/**
+ \def ci_list_head(list)
+ \ingroup LISTS
+ * Return the head of the list
+ */
+#define ci_list_head(list) (list->items != NULL ? list->items->item : NULL)
+
+/**
+ \def ci_list_tail(list)
+ \ingroup LISTS
+ * Return last item of the list.
+ */
+#define ci_list_tail(list) (list->last != NULL ? list->last->item : NULL)
+
 /**
  * Destroy an ci_list_t object 
  \ingroup LISTS
@@ -614,6 +724,30 @@ CI_DECLARE_FUNC(int) ci_list_remove(ci_list_t *list, const void *obj);
  */
 CI_DECLARE_FUNC(const void *) ci_list_search(ci_list_t *list, const void *data);
 
+/**
+ * Return the first found item equal to the obj, using the cmp_func as comparison function.
+ \ingroup LISTS
+ \param list a pointer to the ci_list_t object
+ \param obj pointer to an object to remove
+ \param cmp_func the comparison function to use
+ \return the found item on success, NULL otherwise
+ */
+CI_DECLARE_FUNC(const void *) ci_list_search2(ci_list_t *list, const void *data, int (*cmp_func)(const void *obj, const void *user_data, size_t user_data_size));
+
+/**
+ * Sorts the list using as compare function the default.
+ \ingroup LISTS
+ \param list a pointer to the ci_list_t object
+ */
+CI_DECLARE_FUNC(void) ci_list_sort(ci_list_t *list);
+
+/**
+ * Sorts the list using as compare function the cmp_func.
+ \ingroup LISTS
+ \param list a pointer to the ci_list_t object
+ \param cmp_func the compare function to use
+ */
+CI_DECLARE_FUNC(void) ci_list_sort2(ci_list_t *list, int (*cmp_func)(const void *obj1, const void *obj2, size_t obj_size));
 
 /*
   The following three functions are undocumented. Probably will be removed or replaced 
