@@ -25,6 +25,11 @@
 #include "cfg_param.h"
 #include "ci_threads.h"
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /**
  \defgroup SERVICES Services API
  \ingroup API
@@ -36,6 +41,7 @@
 #define CI_MOD_DONE       1
 #define CI_MOD_CONTINUE 100
 #define CI_MOD_ALLOW204 204
+#define CI_MOD_ALLOW206 206
 #define CI_MOD_ERROR     -1
 
 #define MAX_SERVICE_NAME  63
@@ -57,6 +63,10 @@ struct ci_request;
 
 typedef struct  ci_service_module ci_service_module_t;
 
+enum SERVICE_STATUS {CI_SERVICE_NOT_INITIALIZED=-1, 
+                     CI_SERVICE_OK=0,  
+                     CI_SERVICE_ERROR=1
+};
 
 /**
  \typedef  ci_service_xdata_t
@@ -65,6 +75,7 @@ typedef struct  ci_service_module ci_service_module_t;
  */
 typedef struct ci_service_xdata {
      ci_thread_rwlock_t lock;
+     int status;
      struct ci_conf_entry *intl_srv_conf_table;
      uint64_t xopts;
      char ISTag[SRV_ISTAG_SIZE+1];
@@ -74,7 +85,10 @@ typedef struct ci_service_xdata {
      char TransferComplete[MAX_HEADER_SIZE+1];
      int preview_size;
      int max_connections;
+     int options_ttl;
      int allow_204;
+     int allow_206;
+     int disable_206; /*even if service support it do not use 206*/
      /*statistics IDS*/
      int stat_bytes_in;
      int stat_bytes_out;
@@ -116,12 +130,12 @@ struct  ci_service_module{
      /**
        \brief The service name 
       */
-     char *mod_name;
+     const char *mod_name;
 
     /**
       \brief Service short description 
      */
-     char *mod_short_descr;
+     const char *mod_short_descr;
 
     /**
      \brief Service type 
@@ -253,11 +267,11 @@ typedef struct service_alias {
 
 /*Internal function */
 ci_service_module_t *add_service(ci_service_module_t *service);
-ci_service_module_t *register_service(char *module_file);
+ci_service_module_t *register_service(const char *module_file);
 
-service_alias_t *add_service_alias(char *service_alias,char *service_name,char *args);
-ci_service_module_t *find_service(char *service_name);
-service_alias_t *find_service_alias(char *service_name);
+service_alias_t *add_service_alias(const char *service_alias, const char *service_name,const char *args);
+ci_service_module_t *find_service(const char *service_name);
+service_alias_t *find_service_alias(const char *service_name);
 ci_service_xdata_t *service_data(ci_service_module_t *srv);
 int init_services();
 int post_init_services();
@@ -278,7 +292,7 @@ CI_DECLARE_FUNC(void) ci_service_data_read_unlock(ci_service_xdata_t *srv_xdata)
  \param istag is a string contains the new ISTAG for the service. The istag size can not be more than a size of 
  * SERVICE_ISTAG_SIZE.  If the lenght of istag is greater than SERVICE_ISTAG_SIZE the extra bytes ignored.
  */
-CI_DECLARE_FUNC(void) ci_service_set_istag(ci_service_xdata_t *srv_xdata,char *istag);
+CI_DECLARE_FUNC(void) ci_service_set_istag(ci_service_xdata_t *srv_xdata, const char *istag);
 
 /**
  \ingroup SERVICES
@@ -333,7 +347,7 @@ CI_DECLARE_FUNC(void) ci_service_add_xopts(ci_service_xdata_t *srv_xdata, uint64
  *   ci_service_set_transfer_preview(srv_xdata,"zip, tar");
  \endcode
  */
-CI_DECLARE_FUNC(void) ci_service_set_transfer_preview(ci_service_xdata_t *srv_xdata,char *preview);
+CI_DECLARE_FUNC(void) ci_service_set_transfer_preview(ci_service_xdata_t *srv_xdata,const char *preview);
 
 /**
  \ingroup SERVICES
@@ -349,7 +363,7 @@ CI_DECLARE_FUNC(void) ci_service_set_transfer_preview(ci_service_xdata_t *srv_xd
  *   ci_service_set_transfer_ignore(srv_xdata,"gif, jpeg");
  \endcode
  */
-CI_DECLARE_FUNC(void) ci_service_set_transfer_ignore(ci_service_xdata_t *srv_xdata,char *ignore);
+CI_DECLARE_FUNC(void) ci_service_set_transfer_ignore(ci_service_xdata_t *srv_xdata, const char *ignore);
 
 /**
  \ingroup SERVICES
@@ -365,7 +379,7 @@ CI_DECLARE_FUNC(void) ci_service_set_transfer_ignore(ci_service_xdata_t *srv_xda
  *   ci_service_set_transfer_complete(srv_xdata,"exe, bat, com, ole");
  \endcode
  */
-CI_DECLARE_FUNC(void) ci_service_set_transfer_complete(ci_service_xdata_t *srv_xdata,char *complete);
+CI_DECLARE_FUNC(void) ci_service_set_transfer_complete(ci_service_xdata_t *srv_xdata, const char *complete);
 
 /**
   \ingroup SERVICES
@@ -386,6 +400,15 @@ CI_DECLARE_FUNC(void) ci_service_set_preview(ci_service_xdata_t *srv_xdata, int
  */
 CI_DECLARE_FUNC(void) ci_service_enable_204(ci_service_xdata_t *srv_xdata);
 
+/**
+  \ingroup SERVICES
+  \brief  Enable the Partial Content 206 responses for this service.
+  *
+  * The service will supports the Partial Content 206 responses if the icap client support it too.
+  \param srv_xdata is a pointer to the c-icap internal service data.
+ */
+CI_DECLARE_FUNC(void) ci_service_enable_206(ci_service_xdata_t *srv_xdata);
+
 /**
   \ingroup SERVICES
   \brief Sets the maximum connection should opened by icap client to the c-icap for this service
@@ -395,6 +418,15 @@ CI_DECLARE_FUNC(void) ci_service_enable_204(ci_service_xdata_t *srv_xdata);
  */
 CI_DECLARE_FUNC(void) ci_service_set_max_connections(ci_service_xdata_t *srv_xdata, int max_connections);
 
+/**
+  \ingroup SERVICES
+  \brief Sets the Options ttl for this service
+  *
+  \param srv_xdata is a pointer to the c-icap internal service data.
+  \param ttl is the ttl value in seconds
+ */
+CI_DECLARE_FUNC(void) ci_service_set_options_ttl(ci_service_xdata_t *srv_xdata, int ttl);
+
 CI_DECLARE_FUNC(void) ci_service_add_xincludes(ci_service_xdata_t *srv_xdata, char **xincludes);
 
 #ifdef __CI_COMPAT
@@ -410,5 +442,8 @@ CI_DECLARE_FUNC(void) ci_service_add_xincludes(ci_service_xdata_t *srv_xdata, ch
 
 #endif
 
+#ifdef __cplusplus
+}
+#endif
 
 #endif
