@@ -49,7 +49,7 @@ extern int MAX_KEEPALIVE_REQUESTS;
 extern int MAX_SECS_TO_LINGER;
 extern int MAX_REQUESTS_BEFORE_REALLOCATE_MEM;
 extern int MAX_REQUESTS_PER_CHILD;
-extern struct ci_server_conf CONF;
+extern struct ci_server_conf CI_CONF;
 
 typedef struct server_decl {
      int srv_id;
@@ -232,13 +232,13 @@ static void cancel_all_threads()
      ci_thread_cond_broadcast(&(con_queue->queue_cond));
      /*wait for a milisecond*/
      ci_usleep(1000);
-     servers_running = CONF.THREADS_PER_CHILD;
+     servers_running = CI_CONF.THREADS_PER_CHILD;
      while (servers_running && wait_for_workers >= 0) {
          /*child_data->to_be_killed, may change while we are inside this loop*/
          if (child_data->to_be_killed == IMMEDIATELY) {
              CHILD_HALT = 1;
          }
-         for (i=0; i<CONF.THREADS_PER_CHILD; i++) {
+         for (i=0; i<CI_CONF.THREADS_PER_CHILD; i++) {
              if (threads_list[i] != NULL) { /* if the i thread is still alive*/
                  if (!threads_list[i]->running) { /*if the i thread is not running any more*/
                      ci_debug_printf(5, "Cancel server %d, thread_id %lu (%d)\n",
@@ -257,7 +257,7 @@ static void cancel_all_threads()
                      }
                  }
              }/*the i thread is still alive*/
-         } /* for(i=0;i< CONF.THREADS_PER_CHILD;i++)*/
+         } /* for(i=0;i< CI_CONF.THREADS_PER_CHILD;i++)*/
 
          /*wait for 1 second for the next round*/
          ci_usleep(999999);
@@ -411,7 +411,7 @@ static int server_reconfigure()
       */
      old_childs_queue = childs_queue;
      childs_queue = malloc(sizeof(struct childs_queue));
-     if (!create_childs_queue(childs_queue, 2 * CONF.MAX_SERVERS)) {
+     if (!create_childs_queue(childs_queue, 2 * CI_CONF.MAX_SERVERS)) {
           ci_debug_printf(1,
                           "Cannot init shared memory. Fatal error, exiting!\n");
           return 0;              /*It is not enough. We must wait all childs to exit ..... */
@@ -419,10 +419,10 @@ static int server_reconfigure()
      /*
         Start new childs to handle new requests.
       */
-     if (CONF.START_SERVERS > CONF.MAX_SERVERS)
-          CONF.START_SERVERS = CONF.MAX_SERVERS;
+     if (CI_CONF.START_SERVERS > CI_CONF.MAX_SERVERS)
+          CI_CONF.START_SERVERS = CI_CONF.MAX_SERVERS;
 
-     for (i = 0; i < CONF.START_SERVERS; i++) {
+     for (i = 0; i < CI_CONF.START_SERVERS; i++) {
           start_child(LISTEN_SOCKET);
      }
 
@@ -749,7 +749,7 @@ void listener_thread(int *fd)
                           accept(sockfd,
                                  (struct sockaddr *) &(conn.claddr.sockaddr),
                                  &claddrlen)) == -1)) {
-                         if (errno != EINTR) {
+                         if (errno != EINTR && errno != ECONNABORTED) {
                               ci_debug_printf(1,
                                               "Error accept %d!\nExiting server!\n",
                                               errno);
@@ -762,9 +762,16 @@ void listener_thread(int *fd)
                               ci_debug_printf(5,
                                               "Listener server signalled to exit!\n");
                               goto LISTENER_FAILS;
+                         } else {
+                             ci_debug_printf(2, "Accept failed: errno=%d, ingore!\n", errno);
                          }
                     }
                } while (errno == EINTR && !child_data->to_be_killed);
+
+               // Probably ECONNABORTED or similar error
+               if (conn.fd < 0)
+                   continue;
+
                claddrlen = sizeof(conn.srvaddr.sockaddr);
                getsockname(conn.fd,
                            (struct sockaddr *) &(conn.srvaddr.sockaddr),
@@ -851,11 +858,11 @@ void child_main(int sockfd, int pipefd)
      ci_stat_attach_mem(child_data->stats, child_data->stats_size, NULL);
 
      threads_list =
-         (server_decl_t **) malloc((CONF.THREADS_PER_CHILD + 1) *
+         (server_decl_t **) malloc((CI_CONF.THREADS_PER_CHILD + 1) *
                                    sizeof(server_decl_t *));
-     con_queue = init_queue(CONF.THREADS_PER_CHILD);
+     con_queue = init_queue(CI_CONF.THREADS_PER_CHILD);
 
-     for (i = 0; i < CONF.THREADS_PER_CHILD; i++) {
+     for (i = 0; i < CI_CONF.THREADS_PER_CHILD; i++) {
           if ((threads_list[i] = newthread(con_queue)) == NULL) {
                exit(-1);        // FATAL error.....
           }
@@ -864,7 +871,7 @@ void child_main(int sockfd, int pipefd)
                                (void *) threads_list[i]);
           threads_list[i]->srv_pthread = thread;
      }
-     threads_list[CONF.THREADS_PER_CHILD] = NULL;
+     threads_list[CI_CONF.THREADS_PER_CHILD] = NULL;
      /*Now start the listener thread.... */
      ret = ci_thread_create(&thread, (void *(*)(void *)) listener_thread,
                             (void *) &sockfd);
@@ -941,6 +948,7 @@ int start_child(int fd)
 {
      int pid;
      int pfd[2];
+     int children_num, free_servers, used_servers, max_requests;
 
      if (pipe(pfd) < 0) {
           ci_debug_printf(1,
@@ -955,9 +963,23 @@ int start_child(int fd)
      }
      if ((pid = fork()) == 0) { //A Child .......
           MY_PROC_PID = getpid();
-          attach_childs_queue(childs_queue);
+          if (!attach_childs_queue(childs_queue)) {
+              ci_debug_printf(1, "Can not access shared memory for %d child\n", (int)MY_PROC_PID);
+              exit(-2);
+          }
           child_data =
-              register_child(childs_queue, getpid(), CONF.THREADS_PER_CHILD, pfd[1]);
+              register_child(childs_queue, getpid(), CI_CONF.THREADS_PER_CHILD, pfd[1]);
+          if (!child_data) {
+              childs_queue_stats(childs_queue, &children_num, &free_servers,
+                                 &used_servers, &max_requests);
+              ci_debug_printf(1, "Not available slot in shared memory for %d child (Number of slots: %d, Running children: %d, Free servers: %d, Used servers: %d)!\n", (int)MY_PROC_PID,
+                              childs_queue->size,
+                              children_num,
+                              free_servers,
+                              used_servers
+                  );
+              exit(-3);
+          }
           close(pfd[1]);
           child_main(fd, pfd[0]);
           exit(0);
@@ -1026,21 +1048,22 @@ int start_server()
      char command_buffer[COMMANDS_BUFFER_SIZE];
      int user_informed = 0;
 
-     ctl_socket = ci_named_pipe_create(CONF.COMMANDS_SOCKET);
+     ctl_socket = ci_named_pipe_create(CI_CONF.COMMANDS_SOCKET);
      if (ctl_socket < 0) {
           ci_debug_printf(1,
-                          "Error opening control socket %s. Fatal error, exiting!\n",
-                          CONF.COMMANDS_SOCKET);
+                          "Error opening control socket %s: %s. Fatal error, exiting!\n",
+                          strerror(errno),
+                          CI_CONF.COMMANDS_SOCKET);
           exit(0);
      }
 
-     if (!ci_proc_mutex_init(&accept_mutex)) {
+     if (!ci_proc_mutex_init(&accept_mutex, "accept")) {
           ci_debug_printf(1,
                           "Can't init mutex for accepting conenctions. Fatal error, exiting!\n");
           exit(0);
      }
      childs_queue = malloc(sizeof(struct childs_queue));
-     if (!create_childs_queue(childs_queue, 2 * CONF.MAX_SERVERS)) {
+     if (!create_childs_queue(childs_queue, 2 * CI_CONF.MAX_SERVERS)) {
           ci_proc_mutex_destroy(&accept_mutex);
           ci_debug_printf(1,
                           "Can't init shared memory. Fatal error, exiting!\n");
@@ -1050,10 +1073,10 @@ int start_server()
      init_commands();
      pid = 1;
 #ifdef MULTICHILD
-     if (CONF.START_SERVERS > CONF.MAX_SERVERS)
-          CONF.START_SERVERS = CONF.MAX_SERVERS;
+     if (CI_CONF.START_SERVERS > CI_CONF.MAX_SERVERS)
+          CI_CONF.START_SERVERS = CI_CONF.MAX_SERVERS;
 
-     for (i = 0; i < CONF.START_SERVERS; i++) {
+     for (i = 0; i < CI_CONF.START_SERVERS; i++) {
           if (pid)
                pid = start_child(LISTEN_SOCKET);
      }
@@ -1068,7 +1091,7 @@ int start_server()
                }
                if (ret < 0) {  /*Eof received on pipe. Going to reopen ... */
                     ci_named_pipe_close(ctl_socket);
-                    ctl_socket = ci_named_pipe_open(CONF.COMMANDS_SOCKET);
+                    ctl_socket = ci_named_pipe_open(CI_CONF.COMMANDS_SOCKET);
                     if (ctl_socket < 0) {
                          ci_debug_printf(1,
                                          "Error opening control socket. We are unstable and going down!");
@@ -1100,16 +1123,16 @@ int start_server()
                     kill(childs_queue->childs[child_indx].pid, SIGTERM);
 
                }
-               else if ((freeservers <= CONF.MIN_SPARE_THREADS && childs < CONF.MAX_SERVERS)
-                        || childs < CONF.START_SERVERS) {
+               else if ((freeservers <= CI_CONF.MIN_SPARE_THREADS && childs < CI_CONF.MAX_SERVERS)
+                        || childs < CI_CONF.START_SERVERS) {
                     ci_debug_printf(8,
                                     "Free Servers: %d, children: %d. Going to start a child .....\n",
                                     freeservers, childs);
                     pid = start_child(LISTEN_SOCKET);
                }
-               else if (freeservers >= CONF.MAX_SPARE_THREADS &&
-                        childs > CONF.START_SERVERS &&
-                        (freeservers - CONF.THREADS_PER_CHILD) > CONF.MIN_SPARE_THREADS) {
+               else if (freeservers >= CI_CONF.MAX_SPARE_THREADS &&
+                        childs > CI_CONF.START_SERVERS &&
+                        (freeservers - CI_CONF.THREADS_PER_CHILD) > CI_CONF.MIN_SPARE_THREADS) {
 
                     if ((child_indx = find_an_idle_child(childs_queue)) >= 0) {
                          childs_queue->childs[child_indx].father_said =
@@ -1124,7 +1147,7 @@ int start_server()
 			 user_informed = 0;
                     }
                }
-               else if (childs == CONF.MAX_SERVERS && freeservers < CONF.MIN_SPARE_THREADS) {
+               else if (childs == CI_CONF.MAX_SERVERS && freeservers < CI_CONF.MIN_SPARE_THREADS) {
 		 if(! user_informed) {
 		         ci_debug_printf(1,
 					 "ATTENTION!!!! Not enough available servers (children %d, free servers %d, used servers %d)!!!!! "
@@ -1155,7 +1178,7 @@ int start_server()
 #else
      child_data = (child_shared_data_t *) malloc(sizeof(child_shared_data_t));
      child_data->pid = 0;
-     child_data->freeservers = CONF.THREADS_PER_CHILD;
+     child_data->freeservers = CI_CONF.THREADS_PER_CHILD;
      child_data->usedservers = 0;
      child_data->requests = 0;
      child_data->connections = 0;
