@@ -281,6 +281,7 @@ ci_request_t *ci_request_alloc(ci_connection_t * connection)
      
      req->log_str = NULL;
      req->attributes = NULL;
+     memset(&(req->xclient_ip), 0, sizeof(ci_ip_t));
 
      req->bytes_in = 0;
      req->bytes_out = 0;
@@ -351,6 +352,7 @@ void ci_request_reset(ci_request_t * req)
      if (req->attributes)
          ci_array_destroy(req->attributes);
      req->attributes = NULL;
+     memset(&(req->xclient_ip), 0, sizeof(ci_ip_t));
 
      req->bytes_in = 0;
      req->bytes_out = 0;
@@ -932,7 +934,7 @@ static int client_parse_encaps_header(ci_request_t * req, ci_headers_list_t * h,
           readed =
               (remains >
                req->pstrblock_read_len ? req->pstrblock_read_len : remains);
-          memcpy(h->buf, req->pstrblock_read, readed);
+          memcpy(h->buf + h->bufused, req->pstrblock_read, readed);
           h->bufused += readed;
           req->pstrblock_read = (req->pstrblock_read) + readed;
           req->pstrblock_read_len = (req->pstrblock_read_len) - readed;
@@ -979,44 +981,66 @@ int ci_client_get_server_options(ci_request_t * req, int timeout)
      return CI_OK;
 }
 
-
 ci_connection_t *ci_client_connect_to(char *servername, int port, int proto)
 {
      ci_connection_t *connection = __intl_malloc(sizeof(ci_connection_t));
      char hostname[CI_MAXHOSTNAMELEN + 1];
      unsigned int addrlen = 0;
+     char errBuf[512];
+     int errNo;
+     
      if (!connection)
           return NULL;
-     connection->fd = socket(proto, SOCK_STREAM, 0);
-     if (connection->fd == -1) {
-          ci_debug_printf(1, "Error opening socket ....\n");
-          __intl_free(connection);
-          return NULL;
-     }
 
      if (!ci_host_to_sockaddr_t(servername, &(connection->srvaddr), proto)) {
-	  ci_debug_printf(1, "Error getting address info for host %s\n", servername);
+          ci_debug_printf(1, "Error getting address info for host '%s': %s\n",
+                          servername,
+                          ci_strerror(errno,  errBuf, sizeof(errBuf)));
           close(connection->fd);
           __intl_free(connection);
           return NULL;
      }
      ci_sockaddr_set_port(&(connection->srvaddr), port);
 
+     connection->fd = socket(connection->srvaddr.ci_sin_family, SOCK_STREAM, 0);
+     if (connection->fd == -1) {
+          ci_debug_printf(1, "Error opening socket :%d:%s....\n",
+                          errno,
+                          ci_strerror(errno,  errBuf, sizeof(errBuf)));
+          __intl_free(connection);
+          return NULL;
+     }
+
+#ifdef USE_IPV6
+     if (connection->srvaddr.ci_sin_family == AF_INET6)
+         addrlen = sizeof(struct sockaddr_in6);
+     else
+#endif
+         addrlen = sizeof(struct sockaddr_in);
+
      if (connect
          (connection->fd, (struct sockaddr *) &(connection->srvaddr.sockaddr),
-          CI_SOCKADDR_SIZE)) {
+          addrlen)) {
+          errNo = errno;
           ci_sockaddr_t_to_host(&(connection->srvaddr), hostname,
                                 CI_MAXHOSTNAMELEN);
-          ci_debug_printf(1, "Error connecting to socket (host: %s) .....\n",
-                          hostname);
+          ci_debug_printf(1, "Error connecting to host  '%s': %s \n",
+                          hostname,
+                          ci_strerror(errNo,  errBuf, sizeof(errBuf)));
           close(connection->fd);
           __intl_free(connection);
           return NULL;
      }
 
      addrlen = CI_SOCKADDR_SIZE;
-     getsockname(connection->fd,
-                 (struct sockaddr *) &(connection->claddr.sockaddr), &addrlen);
+     if (getsockname(connection->fd,
+                     (struct sockaddr *) &(connection->claddr.sockaddr), &addrlen)) {
+          ci_debug_printf(1, "Error getting client sockname: %s\n",
+                          ci_strerror(errno,  errBuf, sizeof(errBuf)));
+          close(connection->fd);
+          __intl_free(connection);
+          return NULL;
+     }
      ci_fill_sockaddr(&(connection->claddr));
      ci_fill_sockaddr(&(connection->srvaddr));
 
@@ -1378,8 +1402,8 @@ int ci_client_icapfilter(ci_request_t * req,
 	       ci_headers_reset(req->response_header);
      }
 
-     if (preview_status == 204)
-          return 204;
+     if (preview_status == 204 || preview_status == 206)
+          return preview_status;
 
      ret =
          client_send_get_data(req, timeout, data_source, source_read, data_dest,
@@ -1390,3 +1414,13 @@ int ci_client_icapfilter(ci_request_t * req,
 
      return ret;
 }
+
+/**
+ * Return 1 if the HTTP headers (if any) are read completely
+ * otherwise return 0;
+ */
+int ci_client_http_headers_completed(ci_request_t * req)
+{
+    return (req->status >= GET_PREVIEW);
+}
+
