@@ -25,8 +25,8 @@
 #include "cfg_param.h"
 #include "filetype.h"
 #include "debug.h"
-#ifdef HAVE_REGEX_H
-#include <regex.h>
+#if defined(USE_REGEX)
+#include "ci_regex.h"
 #endif
 
 /*string operators */
@@ -62,7 +62,7 @@ void stringfree(void *key, ci_mem_allocator_t *allocator)
     allocator->free(allocator, key);
 }
 
-ci_type_ops_t  ci_str_ops = {
+const ci_type_ops_t  ci_str_ops = {
     stringdup,
     stringfree,
     stringcmp,
@@ -93,7 +93,7 @@ int string_ext_equal(const void *key1,const void *key2)
 }
 
 
-ci_type_ops_t ci_str_ext_ops = {
+const ci_type_ops_t ci_str_ext_ops = {
     stringdup,
     stringfree,
     string_ext_cmp,
@@ -107,9 +107,17 @@ ci_type_ops_t ci_str_ext_ops = {
 void *int32_dup(const char *str, ci_mem_allocator_t *allocator)
 {
     int32_t *i;
+    char *e = NULL;
     i = allocator->alloc(allocator, sizeof(int32_t));
-    if (i)
-        *i = strtol(str, NULL, 10);    
+    if (i) {
+        *i = strtol(str, &e, 10);
+        if (*e == 'K' || *e == 'k')
+            *i = *i * 1000;
+        else if (*e == 'M' || *e == 'm')
+            *i = *i * 1000000;
+        else if (*e == 'G' || *e == 'g')
+            *i = *i * 1000000000;
+    }
     return (void *)i;
 
 }
@@ -146,7 +154,7 @@ void int32_free(void *key, ci_mem_allocator_t *allocator)
     allocator->free(allocator, key);
 }
 
-ci_type_ops_t  ci_int32_ops = {
+const ci_type_ops_t  ci_int32_ops = {
     int32_dup,
     int32_free,
     int32_cmp,
@@ -158,9 +166,17 @@ ci_type_ops_t  ci_int32_ops = {
 void *uint64_dup(const char *str, ci_mem_allocator_t *allocator)
 {
     uint64_t *i;
+    char *e = NULL;
     i = allocator->alloc(allocator, sizeof(uint64_t));
-    if (i)
-        *i = strtoll(str, NULL, 10);    
+    if (i) {
+        *i = strtoll(str, &e, 10);
+        if (*e == 'K' || *e == 'k')
+            *i = *i * 1000;
+        else if (*e == 'M' || *e == 'm')
+            *i = *i * 1000000;
+        else if (*e == 'G' || *e == 'g')
+        *i = *i * 1000000000;
+    }
     return (void *)i;
 }
 
@@ -195,7 +211,7 @@ size_t uint64_len(const void *key)
     return (size_t)sizeof(uint64_t);
 }
 
-ci_type_ops_t  ci_uint64_ops = {
+const ci_type_ops_t  ci_uint64_ops = {
     uint64_dup,
     uint64_free,
     uint64_cmp,
@@ -205,13 +221,13 @@ ci_type_ops_t  ci_uint64_ops = {
 
 
 /*regular expresion operator definition  */
-#ifdef USE_REGEX
+#if defined(USE_REGEX)
 /*We only need the preg field which holds the compiled regular expression 
   but keep the uncompiled string too just for debuging reasons */
-struct ci_regex {
+struct ci_acl_regex {
     char *str;
     int flags;
-    regex_t preg;
+    ci_regex_t preg;
 };
 
 /*Parse the a regular expression in the form: /regexpression/flags
@@ -221,59 +237,28 @@ struct ci_regex {
 */
 void *regex_dup(const char *str, ci_mem_allocator_t *allocator)
 {
-    struct ci_regex *reg;
-    char *newstr,*s;
-    int slen;
-    unsigned flags;
+    struct ci_acl_regex *reg;
+    char *newstr;
+    int flags, recursive;
 
-    s=(char *)str;
+    newstr = ci_regex_parse(str, &flags, &recursive);
 
-    if(!*s=='/') {
-	ci_debug_printf(1, "Parse error, regex should has the form '/expresion/flags'");
-	return NULL;
-    }
-    s++;
-    slen=strlen(s);
-    newstr = allocator->alloc(allocator,slen+1);    
     if(!newstr) {
-	ci_debug_printf(1,"Error allocating memory for regex_dup!\n");
+	ci_debug_printf(1,"Parse error, while parsing regex: '%s')!\n", str);
 	return NULL;
     }
-    strcpy(newstr, s);
-    s=newstr+slen; /*Points to the end of string*/
-    while(*s!='/' && s!=newstr) s--;
-
-    if(s==newstr) {
-	ci_debug_printf(1,"Parse error, regex should has the form '/expression/flags' (regex=%s)!\n",newstr);
-	allocator->free(allocator, newstr);
-	return NULL;
-    }
-    /*Else found the last '/' char:*/
-    *s='\0';
-    /*parse flags:*/
-    flags=0;
-    s++;
-    while(*s!='\0') {
-	if(*s=='i')
-	    flags = flags | REG_ICASE;
-	else { /*other flags*/
-	}
-        s++;
-    }
-    flags |= REG_EXTENDED; /*or beter the 'e' option?*/
-    flags |= REG_NOSUB; /*we do not need it*/
     
-    reg = allocator->alloc(allocator,sizeof(struct ci_regex));
+    reg = allocator->alloc(allocator,sizeof(struct ci_acl_regex));
     if(!reg) {
 	ci_debug_printf(1,"Error allocating memory for regex_dup (1)!\n");
-	allocator->free(allocator, newstr);
+	free(newstr);
 	return NULL;
     }
 
-    if (regcomp(&(reg->preg), newstr, flags) != 0) {
+    if ((reg->preg = ci_regex_build(newstr, flags)) == NULL) {
 	ci_debug_printf(1, "Error compiling regular expression :%s (%s)\n", str, newstr);
 	allocator->free(allocator, reg);
-	allocator->free(allocator, newstr);
+	free(newstr);
 	return NULL;
     }
 
@@ -285,37 +270,35 @@ void *regex_dup(const char *str, ci_mem_allocator_t *allocator)
 
 int regex_cmp(const void *key1, const void *key2)
 {
-    regmatch_t pmatch[1];
-    struct ci_regex *reg=(struct ci_regex *)key1;
+    struct ci_acl_regex *reg=(struct ci_acl_regex *)key1;
     if (!key2)
         return -1;
-    return regexec(&reg->preg, (char *)key2, 1, pmatch, 0);
+    return (ci_regex_apply(reg->preg, (const char *)key2, strlen(key2), 0, NULL, NULL) == 0 ? 1 : 0);
 }
 
 int regex_equal(const void *key1, const void *key2)
 {
-    regmatch_t pmatch[1];
-    struct ci_regex *reg=(struct ci_regex *)key1;
+    struct ci_acl_regex *reg=(struct ci_acl_regex *)key1;
     if (!key2)
         return 0;
-    return regexec(&reg->preg, (const char *)key2, 1, pmatch, 0)==0;
+    return ci_regex_apply(reg->preg, (const char *)key2, strlen(key2), 0, NULL, NULL) != 0;
 }
 
 size_t regex_len(const void *key)
 {
-    return strlen(((const struct ci_regex *)key)->str);
+    return strlen(((const struct ci_acl_regex *)key)->str);
 }
 
 void regex_free(void *key, ci_mem_allocator_t *allocator)
 {
-    struct ci_regex *reg=(struct ci_regex *)key;
-    regfree(&(reg->preg));
+    struct ci_acl_regex *reg=(struct ci_acl_regex *)key;
+    ci_regex_free(reg->preg);
     allocator->free(allocator, reg->str);
     allocator->free(allocator, reg);
 }
 
 
-ci_type_ops_t  ci_regex_ops = {
+const ci_type_ops_t  ci_regex_ops = {
     regex_dup,
     regex_free,
     regex_cmp,
@@ -391,7 +374,7 @@ void datatype_free(void *key, ci_mem_allocator_t *allocator)
      allocator->free(allocator, key);
 }
    
-ci_type_ops_t  ci_datatype_ops = {
+const ci_type_ops_t  ci_datatype_ops = {
     datatype_dup,
     datatype_free,
     datatype_cmp,
@@ -608,7 +591,7 @@ int ip_sockaddr_equal(const void *ref_key, const void *key_check) {
 
 
 
-ci_type_ops_t  ci_ip_ops = {
+const ci_type_ops_t  ci_ip_ops = {
     ip_dup,
     ip_free,
     ip_cmp,
@@ -618,7 +601,7 @@ ci_type_ops_t  ci_ip_ops = {
 
 
 
-ci_type_ops_t ci_ip_sockaddr_ops = {
+const ci_type_ops_t ci_ip_sockaddr_ops = {
     ip_dup,
     ip_free,
     ip_sockaddr_cmp,
